// Rails timeago bootstrap with all locales
//= require rails-timeago
//= require locales/jquery.timeago.af.js
//= require locales/jquery.timeago.am.js
//= require locales/jquery.timeago.ar.js
//= require locales/jquery.timeago.az-short.js
//= require locales/jquery.timeago.az.js
//= require locales/jquery.timeago.be.js
//= require locales/jquery.timeago.bg.js
//= require locales/jquery.timeago.bs.js
//= require locales/jquery.timeago.ca.js
//= require locales/jquery.timeago.cs.js
//= require locales/jquery.timeago.cy.js
//= require locales/jquery.timeago.da.js
//= require locales/jquery.timeago.de-short.js
//= require locales/jquery.timeago.de.js
//= require locales/jquery.timeago.dv.js
//= require locales/jquery.timeago.el.js
//= require locales/jquery.timeago.en-short.js
//= require locales/jquery.timeago.es-short.js
//= require locales/jquery.timeago.es.js
//= require locales/jquery.timeago.et.js
//= require locales/jquery.timeago.eu.js
//= require locales/jquery.timeago.fa-short.js
//= require locales/jquery.timeago.fa.js
//= require locales/jquery.timeago.fi.js
//= require locales/jquery.timeago.fr-short.js
//= require locales/jquery.timeago.fr.js
//= require locales/jquery.timeago.gl.js
//= require locales/jquery.timeago.he.js
//= require locales/jquery.timeago.hr.js
//= require locales/jquery.timeago.hu.js
//= require locales/jquery.timeago.hy.js
//= require locales/jquery.timeago.id.js
//= require locales/jquery.timeago.is.js
//= require locales/jquery.timeago.it-short.js
//= require locales/jquery.timeago.it.js
//= require locales/jquery.timeago.ja.js
//= require locales/jquery.timeago.jv.js
//= require locales/jquery.timeago.ko.js
//= require locales/jquery.timeago.ky.js
//= require locales/jquery.timeago.lt.js
//= require locales/jquery.timeago.lv.js
//= require locales/jquery.timeago.mk.js
//= require locales/jquery.timeago.nl.js
//= require locales/jquery.timeago.no.js
//= require locales/jquery.timeago.pl.js
//= require locales/jquery.timeago.pt-br-short.js
//= require locales/jquery.timeago.pt-br.js
//= require locales/jquery.timeago.pt-short.js
//= require locales/jquery.timeago.pt.js
//= require locales/jquery.timeago.ro.js
//= require locales/jquery.timeago.rs.js
//= require locales/jquery.timeago.ru.js
//= require locales/jquery.timeago.rw.js
//= require locales/jquery.timeago.si.js
//= require locales/jquery.timeago.sk.js
//= require locales/jquery.timeago.sl.js
//= require locales/jquery.timeago.sq.js
//= require locales/jquery.timeago.sr.js
//= require locales/jquery.timeago.sv.js
//= require locales/jquery.timeago.th.js
//= require locales/jquery.timeago.tr-short.js
//= require locales/jquery.timeago.tr.js
//= require locales/jquery.timeago.uk.js
//= require locales/jquery.timeago.ur.js
//= require locales/jquery.timeago.uz.js
//= require locales/jquery.timeago.vi.js
//= require locales/jquery.timeago.zh-CN.js
//= require locales/jquery.timeago.zh-TW.js
